"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultTemplateValidator = void 0;
const tslib_1 = require("tslib");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
const validators_1 = require("./validators");
class DefaultTemplateValidator {
    constructor(validator) {
        this.validator = validator;
    }
    validate(template) {
        const prevErrors = this.validator ? this.validator.validate(template) : [];
        const { error } = validators_1.validators.validate(template, { abortEarly: false });
        const errors = error
            ? error.details.map((error) => lodash_1.default.pick(error, ["type", "path", "message"]))
            : [];
        return [...prevErrors, ...errors];
    }
    getComponents(template) {
        return this.validator ? this.validator.getComponents(template) : {};
    }
}
exports.DefaultTemplateValidator = DefaultTemplateValidator;
